==> auth-2.4.1002-sources.jar: com/zing/zalo/zalosdk/auth/internal/c.java <==
package com.zing.zalo.zalosdk.auth.internal;

import android.content.Context;
import android.content.DialogInterface;
import android.content.DialogInterface.OnDismissListener;
import android.os.Bundle;
import android.os.Handler;
import android.widget.ImageView;
import android.widget.TextView;
import com.zing.zalo.zalosdk.R;
import com.zing.zalo.zalosdk.core.log.Log;

public class c extends b implements OnDismissListener {
    String a = c.class.getSimpleName();
    String b;
    String c;
    String d;
    String e;
    String f;
    public boolean g = false;
    boolean h = false;
    int i = 0;
    Handler j = new Handler();
    Runnable k = new Runnable(this) {
        final /* synthetic */ c a;

        {
            this.a = this$0;
        }

        public final void run() {
            if (this.a.i > 0 && this.a.isShowing()) {
                this.a.b();
                if (this.a.n != null) {
                    this.a.n.onClose();
                }
            }
        }
    };
    Runnable l = new Runnable(this) {
        final /* synthetic */ c a;

        {
            this.a = this$0;
        }

        public final void run() {
            if (this.a.g) {
                c cVar = this.a;
                ((TextView) cVar.findViewById(R.id.zalosdk_message_ctl)).setText(this.a.f);
            }
        }
    };
    Runnable m = new Runnable(this) {
        final /* synthetic */ c a;

        {
            this.a = this$0;
        }

        public final void run() {
            Log.i("THREAD START", "time out " + this.a.g + " " + this.a.i);
            if (this.a.g && this.a.i == 0) {
                this.a.b();
                c cVar = this.a;
                int i = b.TIMEOUT$5a1610ce;
                cVar.show();
                cVar.g = true;
                ImageView imageView;
                switch (AnonymousClass4.a[i - 1]) {
                    case 1:
                        Log.i("THREAD BEGIN", "PROCESSING!!");
                        ((TextView) cVar.findViewById(R.id.zalosdk_message_ctl)).setText(cVar.b);
                        cVar.findViewById(R.id.zalosdk_status_ctl).setVisibility(8);
                        cVar.findViewById(R.id.zalosdk_indicator_ctl).setVisibility(0);
                        cVar.setCancelable(false);
                        cVar.i = 0;
                        return;
                    case 2:
                        Log.i(cVar.a, "Show success dialog");
                        ((TextView) cVar.findViewById(R.id.zalosdk_message_ctl)).setText(cVar.c);
                        cVar.findViewById(R.id.zalosdk_indicator_ctl).setVisibility(8);
                        imageView = (ImageView) cVar.findViewById(R.id.zalosdk_status_ctl);
                        imageView.setImageResource(R.drawable.zalosdk_ic_success);
                        imageView.setVisibility(0);
                        cVar.setCancelable(true);
                        cVar.i = 1;
                        cVar.a();
                        return;
                    case 3:
                        ((TextView) cVar.findViewById(R.id.zalosdk_message_ctl)).setText(cVar.d);
                        cVar.findViewById(R.id.zalosdk_indicator_ctl).setVisibility(8);
                        imageView = (ImageView) cVar.findViewById(R.id.zalosdk_status_ctl);
                        imageView.setImageResource(R.drawable.zalosdk_ic_fail);
                        imageView.setVisibility(0);
                        cVar.setCancelable(true);
                        cVar.i = 1;
                        cVar.a();
                        return;
                    case 4:
                        Log.i("debuglog", "time out showview");
                        cVar.findViewById(R.id.zalosdk_process_dialog_ctl).setVisibility(8);
                        cVar.setCancelable(true);
                        cVar.i = 1;
                        cVar.j.postDelayed(cVar.k, 1);
                        cVar.h = true;
                        return;
                    default:
                        return;
                }
            }
        }
    };
    a n;

    static /* synthetic */ class AnonymousClass4 {
        static final /* synthetic */ int[] a = new int[b.a().length];

        static {
            try {
                a[b.PROCESSING$5a1610ce - 1] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                a[b.SUCCESS$5a1610ce - 1] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                a[b.FAILED$5a1610ce - 1] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                a[b.TIMEOUT$5a1610ce - 1] = 4;
            } catch (NoSuchFieldError e4) {
            }
        }
    }

    public interface a {
        void onClose();
    }

    public enum b {
        ;
        
        public static final int FAILED$5a1610ce = 0;
        public static final int PROCESSING$5a1610ce = 0;
        public static final int SUCCESS$5a1610ce = 0;
        public static final int TIMEOUT$5a1610ce = 0;

        public static int[] a() {
            return (int[]) $VALUES$ad1396d.clone();
        }

        static {
            PROCESSING$5a1610ce = 1;
            SUCCESS$5a1610ce = 2;
            FAILED$5a1610ce = 3;
            TIMEOUT$5a1610ce = 4;
            $VALUES$ad1396d = new int[]{PROCESSING$5a1610ce, SUCCESS$5a1610ce, FAILED$5a1610ce, TIMEOUT$5a1610ce};
        }
    }

    public c(Context context, a listener) {
        super(context);
        this.n = listener;
        setOnDismissListener(this);
        this.b = g.a("zalosdk_processing");
        this.c = g.a("zalosdk_success");
        this.d = g.a("zalosdk_unsuccess");
        this.e = g.a("zalosdk_atm_processing");
        this.f = g.a("zalosdk_atm_processing_waiting");
    }

    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.zalosdk_activity_processing);
    }

    final void a() {
        this.j.postDelayed(this.k, 3000);
    }

    public void onDismiss(DialogInterface dialogInterface) {
        if (this.n != null) {
            Log.i(getClass().getName(), "cancel");
            this.n.onClose();
        }
    }

    public void onBackPressed() {
    }

    public final void b() {
        this.g = false;
        hide();
    }

    public void show() {
        Log.i(this.a, "show loading..");
        try {
            super.show();
        } catch (Exception e) {
            Log.i(this.a, "error can not show loading");
        }
    }

    public void hide() {
        Log.i(this.a, "hide loading!");
        super.hide();
    }
}

==> auth-2.4.1601.1-sources.jar: com/zing/zalo/zalosdk/auth/internal/c.java <==
package com.zing.zalo.zalosdk.auth.internal;

import android.content.Context;
import android.content.DialogInterface;
import android.content.DialogInterface.OnDismissListener;
import android.os.Bundle;
import android.os.Handler;
import android.widget.ImageView;
import android.widget.TextView;
import com.zing.zalo.zalosdk.R;
import com.zing.zalo.zalosdk.core.log.Log;

public class c extends b implements OnDismissListener {
    String a = c.class.getSimpleName();
    String b;
    String c;
    String d;
    String e;
    String f;
    public boolean g = false;
    boolean h = false;
    int i = 0;
    Handler j = new Handler();
    Runnable k = new Runnable(this) {
        final /* synthetic */ c a;

        {
            this.a = r1;
        }

        public final void run() {
            if (this.a.i > 0 && this.a.isShowing()) {
                this.a.b();
                if (this.a.n != null) {
                    this.a.n.onClose();
                }
            }
        }
    };
    Runnable l = new Runnable(this) {
        final /* synthetic */ c a;

        {
            this.a = r1;
        }

        public final void run() {
            if (this.a.g) {
                c cVar = this.a;
                ((TextView) cVar.findViewById(R.id.zalosdk_message_ctl)).setText(this.a.f);
            }
        }
    };
    Runnable m = new Runnable(this) {
        final /* synthetic */ c a;

        {
            this.a = r1;
        }

        public final void run() {
            Log.i("THREAD START", "time out " + this.a.g + " " + this.a.i);
            if (this.a.g && this.a.i == 0) {
                this.a.b();
                c cVar = this.a;
                int i = b.TIMEOUT$5a1610ce;
                cVar.show();
                cVar.g = true;
                ImageView imageView;
                switch (AnonymousClass4.a[i - 1]) {
                    case 1:
                        Log.i("THREAD BEGIN", "PROCESSING!!");
                        ((TextView) cVar.findViewById(R.id.zalosdk_message_ctl)).setText(cVar.b);
                        cVar.findViewById(R.id.zalosdk_status_ctl).setVisibility(8);
                        cVar.findViewById(R.id.zalosdk_indicator_ctl).setVisibility(0);
                        cVar.setCancelable(false);
                        cVar.i = 0;
                        return;
                    case 2:
                        Log.i(cVar.a, "Show success dialog");
                        ((TextView) cVar.findViewById(R.id.zalosdk_message_ctl)).setText(cVar.c);
                        cVar.findViewById(R.id.zalosdk_indicator_ctl).setVisibility(8);
                        imageView = (ImageView) cVar.findViewById(R.id.zalosdk_status_ctl);
                        imageView.setImageResource(R.drawable.zalosdk_ic_success);
                        imageView.setVisibility(0);
                        cVar.setCancelable(true);
                        cVar.i = 1;
                        cVar.a();
                        return;
                    case 3:
                        ((TextView) cVar.findViewById(R.id.zalosdk_message_ctl)).setText(cVar.d);
                        cVar.findViewById(R.id.zalosdk_indicator_ctl).setVisibility(8);
                        imageView = (ImageView) cVar.findViewById(R.id.zalosdk_status_ctl);
                        imageView.setImageResource(R.drawable.zalosdk_ic_fail);
                        imageView.setVisibility(0);
                        cVar.setCancelable(true);
                        cVar.i = 1;
                        cVar.a();
                        return;
                    case 4:
                        Log.i("debuglog", "time out showview");
                        cVar.findViewById(R.id.zalosdk_process_dialog_ctl).setVisibility(8);
                        cVar.setCancelable(true);
                        cVar.i = 1;
                        cVar.j.postDelayed(cVar.k, 1);
                        cVar.h = true;
                        return;
                    default:
                        return;
                }
            }
        }
    };
    a n;

    static /* synthetic */ class AnonymousClass4 {
        static final /* synthetic */ int[] a = new int[b.a().length];

        static {
            try {
                a[b.PROCESSING$5a1610ce - 1] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                a[b.SUCCESS$5a1610ce - 1] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                a[b.FAILED$5a1610ce - 1] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                a[b.TIMEOUT$5a1610ce - 1] = 4;
            } catch (NoSuchFieldError e4) {
            }
        }
    }

    public interface a {
        void onClose();
    }

    public enum b {
        ;
        
        public static final int FAILED$5a1610ce = 0;
        public static final int PROCESSING$5a1610ce = 0;
        public static final int SUCCESS$5a1610ce = 0;
        public static final int TIMEOUT$5a1610ce = 0;

        static {
            PROCESSING$5a1610ce = 1;
            SUCCESS$5a1610ce = 2;
            FAILED$5a1610ce = 3;
            TIMEOUT$5a1610ce = 4;
            $VALUES$ad1396d = new int[]{PROCESSING$5a1610ce, SUCCESS$5a1610ce, FAILED$5a1610ce, TIMEOUT$5a1610ce};
        }

        public static int[] a() {
            return (int[]) $VALUES$ad1396d.clone();
        }
    }

    public c(Context context, a aVar) {
        super(context);
        this.n = aVar;
        setOnDismissListener(this);
        this.b = k.a("zalosdk_processing");
        this.c = k.a("zalosdk_success");
        this.d = k.a("zalosdk_unsuccess");
        this.e = k.a("zalosdk_atm_processing");
        this.f = k.a("zalosdk_atm_processing_waiting");
    }

    final void a() {
        this.j.postDelayed(this.k, 3000);
    }

    public final void b() {
        this.g = false;
        hide();
    }

    public void hide() {
        Log.i(this.a, "hide loading!");
        super.hide();
    }

    public void onBackPressed() {
    }

    protected void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        setContentView(R.layout.zalosdk_activity_processing);
    }

    public void onDismiss(DialogInterface dialogInterface) {
        if (this.n != null) {
            Log.i(getClass().getName(), "cancel");
            this.n.onClose();
        }
    }

    public void show() {
        Log.i(this.a, "show loading..");
        try {
            super.show();
        } catch (Exception e) {
            Log.i(this.a, "error can not show loading");
        }
    }
}
